==> vue-element-ui-plus-1.0.29.tgz: package/webpack/webpack.ui.js <==
const fs = require('fs')
const path = require('path')
const baseConfig = require('./webpack.base')
const { merge } = require('webpack-merge')
// 清除构建目录
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const VueLoaderPlugin = require('vue-loader/lib/plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const TerserPlugin = require('terser-webpack-plugin')


const resolve = name => {
    return path.resolve(__dirname, name)
}
const dir = resolve('../packages')
const files = fs.readdirSync(dir)
let modules = {}

files.forEach(name => {
    name = name.replace(/(\.\/|\.js)$/g, '')
    modules[name] = path.join(__dirname, '../packages', name)
})

const config = {
    mode: 'production',
    entry: modules,
    output: {
        path: path.resolve(__dirname, '../lib'),
        filename: '[name].js',
        libraryTarget: 'umd',
        library: 'vue-element-ui-plus',
        libraryExport: 'default'
    },
    externals: {
        vue: 'Vue',
        'element-ui': 'ELEMENT'
    },
    optimization: {
        minimize: true,
        minimizer: [
            new TerserPlugin({
                extractComments: false,
                terserOptions: {
                    format: {
                        comments: false,
                    },
                },
            }),
        ],
    },
    plugins: [
        new VueLoaderPlugin(),
        new CleanWebpackPlugin(),
        new MiniCssExtractPlugin({
            filename: '../lib/css/[name].css'
        })
    ]
}

module.exports = merge(config, baseConfig)

==> vue-element-ui-plus-1.0.39.tgz: package/webpack/webpack.ui.js <==
const fs = require('fs')
const path = require('path')
const baseConfig = require('./webpack.base')
const { merge } = require('webpack-merge')
// 清除构建目录
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const VueLoaderPlugin = require('vue-loader/lib/plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const TerserPlugin = require('terser-webpack-plugin')
const components = require('../components.json');

const resolve = name => {
    return path.resolve(__dirname, name)
}

let modules = {}

Object.keys(components).forEach(name => {
    modules[name] = path.join(__dirname, '../', components[name])
})
console.log(modules)

const config = {
    mode: 'production',
    entry: modules,
    output: {
        path: path.resolve(__dirname, '../lib'),
        filename: '[name].js',
        libraryTarget: 'umd',
        library: 'vue-element-ui-plus',
        libraryExport: 'default'
    },
    externals: {
        vue: {
            root: 'Vue',
            commonjs: 'vue',
            commonjs2: 'vue',
            amd: 'vue'
        },
        'element-ui': {
            root: 'ELEMENT',
            commonjs: 'element-ui',
            commonjs2: 'element-ui',
            amd: 'element-ui',
        }
    },
    optimization: {
        minimize: true,
        minimizer: [
            new TerserPlugin({
                extractComments: false,
                terserOptions: {
                    format: {
                        comments: false,
                    },
                },
            }),
        ],
    },
    plugins: [
        new VueLoaderPlugin(),
        new CleanWebpackPlugin(),
        new MiniCssExtractPlugin({
            filename: '../lib/css/[name].css'
        })
    ]
}

module.exports = merge(config, baseConfig)
